#! /usr/bin/env bash

# Go to script directory
cd "$(dirname $0)"

echo "[INFO]: Setting up..."

# Declare directory variables
PROJECT_DIR=$(pwd)/..
CONFIG_DIR=$PROJECT_DIR/config
DATA_DIR=$PROJECT_DIR/data

# Declare YOLOv3 variables
YOLOV3_FILE_CONFIG="yolov3.cfg"
YOLOV3_FILE_INPUT="dog-cycle-car.png"
YOLOV3_FILE_WEIGHTS="yolov3.weights"
YOLOV3_FILE_URL_CONFIG="https://raw.githubusercontent.com/AlexeyAB/darknet/master/cfg/$YOLOV3_FILE_CONFIG"
YOLOV3_FILE_URL_INPUT="https://github.com/ayooshkathuria/pytorch-yolo-v3/raw/master/$YOLOV3_FILE_INPUT"
YOLOV3_FILE_URL_WEIGHTS="https://pjreddie.com/media/files/$YOLOV3_FILE_WEIGHTS"

# Declare COCO variables
COCO_FILE_NAMES="coco.names"
COCO_FILE_URL_NAMES="https://github.com/AlexeyAB/darknet/raw/master/data/$COCO_FILE_NAMES"

# Create directories
echo "[INFO]: Creating configuration and data directories..."
mkdir -p "$CONFIG_DIR"
mkdir -p "$DATA_DIR"
RETURN=$?
if [ $RETURN -ne 0 ]
then
	echo "[ERROR]: Setup failed. Quit."
	exit $RETURN
fi

# Download YOLOv3 configuration file
echo "[INFO]: Downloading YOLOv3 configuration file..."
if [ ! -f "$CONFIG_DIR/$YOLOV3_FILE_CONFIG" ]
then
	cd "$CONFIG_DIR"
	curl -L --progress-bar "$YOLOV3_FILE_URL_CONFIG" -o "$YOLOV3_FILE_CONFIG"

	RETURN=$?
	if [ $RETURN -ne 0 ]
	then
		echo "[ERROR]: Setup failed. Quit."
		exit $RETURN
	fi
else
	echo "[INFO]: YOLOv3 configuration file exists. Skip."
fi

# Download YOLOv3 input file
echo "[INFO]: Downloading YOLOv3 input file..."
if [ ! -f "$DATA_DIR/$YOLOV3_FILE_INPUT" ]
then
	cd "$DATA_DIR"
	curl -L --progress-bar "$YOLOV3_FILE_URL_INPUT" -o "$YOLOV3_FILE_INPUT"

	RETURN=$?
	if [ $RETURN -ne 0 ]
	then
		echo "[ERROR]: Setup failed. Quit."
		exit $RETURN
	fi
else
	echo "[INFO]: YOLOv3 input file exists. Skip."
fi

# Download YOLOv3 weights file
echo "[INFO]: Downloading YOLOv3 weights file..."
if [ ! -f "$DATA_DIR/$YOLOV3_FILE_WEIGHTS" ]
then
	cd "$DATA_DIR"
	curl -L --progress-bar "$YOLOV3_FILE_URL_WEIGHTS" -o "$YOLOV3_FILE_WEIGHTS"

	RETURN=$?
	if [ $RETURN -ne 0 ]
	then
		echo "[ERROR]: Setup failed. Quit."
		exit $RETURN
	fi
else
	echo "[INFO]: YOLOv3 weights file exists. Skip."
fi

# Download COCO names file
echo "[INFO]: Downloading COCO names file..."
if [ ! -f "$DATA_DIR/$COCO_FILE_NAMES" ]
then
	cd "$DATA_DIR"
	curl -L --progress-bar "$COCO_FILE_URL_NAMES" -o "$COCO_FILE_NAMES"

	RETURN=$?
	if [ $RETURN -ne 0 ]
	then
		echo "[ERROR]: Setup failed. Quit."
		exit $RETURN
	fi
else
	echo "[INFO]: COCO names file exists. Skip."
fi

echo "[INFO]: Setup completed."
