import header
import mapcalc
import numpy
import os

def get_imageId_for_file(file_name_input, file_ground_truth):
    file_name_input = os.path.join(header.file_path_name_input, file_name_input)

    for key in file_ground_truth.imgs.keys():
        f_filename = "/".join(file_name_input.split("/")[-3:])

        if file_ground_truth.imgs[key]["file_name"] == f_filename:
            image_id = file_ground_truth.imgs[key]["id"]
            return image_id

def get_formatted_gt_for_mAP(file_name_input, file_ground_truth, file_ground_truth_formatted):
    image_id = get_imageId_for_file(file_name_input, file_ground_truth)
    output = file_ground_truth_formatted[str(image_id)]
    return numpy.array(output)

def format_predict_for_mAP(bounding_boxes):
    output = []

    for box in bounding_boxes:
        formatted_bbox = []

        formatted_bbox.append(box[0])
        formatted_bbox.append(box[1])
        formatted_bbox.append(box[2])
        formatted_bbox.append(box[3])
        formatted_bbox.append(int(box[6] + 1)) # class_id
        formatted_bbox.append(box[5]) # confidence

        output.append(formatted_bbox)

    return numpy.array(output)

def format_for_mAP(bounding_boxes, file_name_input, file_ground_truth, file_ground_truth_formatted, evaluation_class = None):
    formatted_predict_for_mAP = format_predict_for_mAP(bounding_boxes)
    formatted_gt_for_mAP = get_formatted_gt_for_mAP(file_name_input, file_ground_truth, file_ground_truth_formatted)

    # format gt
    ground_truth = {}
    ground_truth_all = {}
    gt_boxes = []
    gt_boxes_all = []
    gt_labels = []
    gt_labels_all = []

    for detects in formatted_gt_for_mAP:
        box = []
        box.extend(detects[:4])
        class_id = detects[4]

        gt_boxes_all.append(box)
        gt_labels_all.append(class_id)

        if evaluation_class is not None and class_id != evaluation_class + 1:
            continue

        gt_boxes.append(box)
        gt_labels.append(class_id)

    ground_truth["boxes"] = gt_boxes
    ground_truth["labels"] = gt_labels
    ground_truth_all["boxes"] = gt_boxes_all
    ground_truth_all["labels"] = gt_labels_all

    if len(gt_boxes) == 0:
        return (1.0, ground_truth_all)

    # format preds
    result_dict = {}
    preds_boxes = []
    preds_labels = []
    preds_scores = []

    for detects in formatted_predict_for_mAP:
        class_id = detects[4]

        if evaluation_class is not None and class_id != evaluation_class + 1:
            continue

        box = []
        box.extend(detects[:4])
        preds_boxes.append(box)
        preds_labels.append(detects[4])
        preds_scores.append(detects[5])

    result_dict["boxes"] = preds_boxes
    result_dict["labels"] = preds_labels
    result_dict["scores"] = preds_scores

    return (mapcalc.calculate_map_range(ground_truth, result_dict, 0.05, 0.95, 0.05), ground_truth_all)
